pub struct ChannelSendMessageResult {
pub message_id: Option<String>,
pub receipt: Option<MessageReceipt>,
pub raw: Option<Value>,
}Expand description
Result returned by send_message.
Fields
message_id: Option<String>receipt: Option<MessageReceipt>raw: Option<Value>Trait Implementations
Sourceimpl Clone for ChannelSendMessageResult
impl Clone for ChannelSendMessageResult
Sourcefn clone(&self) -> ChannelSendMessageResult
fn clone(&self) -> ChannelSendMessageResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelSendMessageResult
impl Debug for ChannelSendMessageResult
Sourceimpl Default for ChannelSendMessageResult
impl Default for ChannelSendMessageResult
Sourcefn default() -> ChannelSendMessageResult
fn default() -> ChannelSendMessageResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ChannelSendMessageResultwhere
ChannelSendMessageResult: Default,
impl<'de> Deserialize<'de> for ChannelSendMessageResultwhere
ChannelSendMessageResult: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChannelSendMessageResult
impl JsonSchema for ChannelSendMessageResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChannelSendMessageResult
impl RefUnwindSafe for ChannelSendMessageResult
impl Send for ChannelSendMessageResult
impl Sync for ChannelSendMessageResult
impl Unpin for ChannelSendMessageResult
impl UnsafeUnpin for ChannelSendMessageResult
impl UnwindSafe for ChannelSendMessageResult